package com.supermap.openlocaldata;

import com.supermap.data.Environment;
import com.supermap.data.LicenseStatus;
import com.supermap.data.Workspace;
import com.supermap.data.WorkspaceConnectionInfo;
import com.supermap.data.WorkspaceType;
import com.supermap.realspace.*;
import com.supermap.realspace.SceneControl.SceneControlInitedCallBackListenner;
import android.annotation.SuppressLint;
import android.app.Activity;
import android.os.Bundle;
import android.widget.Toast;

/**
 * <p>
 * Title: Initialize to load the local scene and avoid the white ball.
 * </p>
 * 
 * <p>
 * Description:
 * ============================================================================>
 * ------------------------------Statement----------------------------
 * This is SuperMap iMobile for Android Sample Code 
 * Copyright: SuperMap Software Co., Ltd.
 * ----------------------------------------------------------------
 * ---------------------SuperMap iMobile for Android Sample Code------------------------
 * 
 * 1. Introduction: How to open a local scene data 2. Data: none 3. Members: SceneControl.getScene
 * Scene.open 
 * 
 * 4. Steps: (1)Copy the data in SampleData/Everest/ to the Android sd /sdcard/SampleData/
 * (2)sceneName changed to the published 3D scene name (3)Open the scene.
 * ----------------------------------------
 * --------------------------------------
 * ============================================================================>
 * </p>
 * <p>
 * Company: SuperMap Software Co., Ltd.
 * </p>
 * 
 */

@SuppressLint({ "HandlerLeak", "ShowToast", "SdCardPath" })
public class MainActivity extends Activity {
	private Workspace m_workspace;
	private Scene m_scene;
	private SceneControl mSceneControl;
	// Offline 3D scene data name
	String workspacePath = "/sdcard/SampleData/Everest/珠峰.sxwu";
	// 3D scene name
	String sceneName = "珠峰";
	WorkspaceConnectionInfo info;
	WorkspaceType workspaceTypetemp = null;
	// The first time to start
	boolean firstStart = false;
	final int SCENECONTROL_INITED = 0;

	boolean isLicenseAvailable = false;
	private final String sdcard = android.os.Environment.getExternalStorageDirectory().getAbsolutePath().toString();
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		Environment.setLicensePath(sdcard+"/SuperMap/license/");
		Environment.initialization(this);
		info = new WorkspaceConnectionInfo();
		setContentView(R.layout.activity_main);
		mSceneControl = (SceneControl) findViewById(R.id.sceneControl);
		// Get the current license.
		isLicenseAvailable = isLicenseAvailable();
		// Get the scene control. Open the local scene.
		mSceneControl.sceneControlInitedComplete(new SceneControlInitedCallBackListenner(){

			@Override
			public void onSuccess(String success) {
				if (!firstStart && isLicenseAvailable) {
					openLocalScene();
					firstStart = true;
				}
				
			}
			
		});

	}

	// Open a local scene
	private void openLocalScene() {

		// Create a new workspace object
		if (m_workspace == null) {
			m_workspace = new Workspace();
		}
		// Set the service path and type information.
		workspaceTypetemp = WorkspaceType.SXWU;
		info.setServer(workspacePath);
		info.setType(workspaceTypetemp);
		// Scene is associated to the workspace
		if (m_workspace.open(info)) {
			m_scene = mSceneControl.getScene();
			m_scene.setWorkspace(m_workspace);
		}
		// Open the scene
		boolean successed = mSceneControl.getScene().open(sceneName);
		if (successed) {
			Toast.makeText(MainActivity.this, "Open the scene successfully", Toast.LENGTH_LONG);
		}
	}

	// Whether the license is available
	@SuppressLint("ShowToast")
	private boolean isLicenseAvailable() {
		LicenseStatus licenseStatus = Environment.getLicenseStatus();
		if (!licenseStatus.isLicenseExsit()) {
			Toast.makeText(MainActivity.this, "License does not exist. Failed to open the scene. Please add the license", Toast.LENGTH_LONG).show();
			return false;
		} else if (!licenseStatus.isLicenseValid()) {
			Toast.makeText(MainActivity.this, "The license is expired. Failed to open the scene. Please change the license", Toast.LENGTH_LONG).show();
			return false;
		}
		return true;
	}
}